#include <SoftPWM.h>

// RGB
int D1[4] = {2,3,4}; // Duct 1 pins
int D4[4] = {5,6,9}; // Duct 4 pins 
int D2[4] = {7,8,12}; // Duct 2 pins
int D3[4] = {10,11,13}; // Duct 3 pins  

#define RadioIn_A 2 // INTERRUPT number
#define RadioIn_A_PIN 0 // INTERRUPT Pin (of the above interrupt

volatile int RadioIn_A_PW;// Pulse Width in uS
volatile unsigned long RadioIn_A_PW_Start = 0; // set in the interrupt
volatile boolean RadioIn_A_SignalNew = false; // set in the interrupt and read in the loop

void setup()
{  
  // Initialize
  SoftPWMBegin(); // Begin 'Soft PWM'
  // Create and set pins to 0 (off)
  for (int i=2; i <= 13; i++){SoftPWMSet(i, 0);}    
  for (int i=1; i <= 13; i++){SoftPWMSetFadeTime(i, 1000, 1000);} 
  
  attachInterrupt(RadioIn_A,RadioIn_A_PulseWidth,CHANGE);
}

// Pattern Matrix
//    R,G,B
// D1 1,0,0
// D2 0,1,0
// D3 0,1,0
// D4 1,0,0
// c = count, t=time in ms ,d1r = Duct 1 colour R, d2r= Duct 2 colour R, d2b= Duct 2 colour B

void loop()
{
  if(RadioIn_A_PW < 1400) 
    {SetLights(1,600,1,0,0,1,0,0,1,0,0,1,0,0);}
  if(RadioIn_A_PW >= 1300 && RadioIn_A_PW < 1700)
    {SetLights(1,400,1,1,1,1,1,1,1,1,1,1,1,1);}
  if(RadioIn_A_PW >= 1700) 
    {SetLights(1,200,0,0,1,1,0,0,0,0,1,1,0,0);} 
}


void SetLights(int c,int t,int d1r,int d1g,int d1b,int d2r,int d2g,int d2b,int d3r,int d3g,int d3b,int d4r,int d4g,int d4b)
{  
  for(int n=1;n<=c;n++)
  {
    SoftPWMSetPercent(D1[0], (d1r*100));
    SoftPWMSetPercent(D1[1], (d1g*100));
    SoftPWMSetPercent(D1[2], (d1b*100));
    SoftPWMSetPercent(D2[0], (d2r*100));
    SoftPWMSetPercent(D2[1], (d2g*100));
    SoftPWMSetPercent(D2[2], (d2b*100));
    SoftPWMSetPercent(D3[0], (d3r*100));
    SoftPWMSetPercent(D3[1], (d3g*100));
    SoftPWMSetPercent(D3[2], (d3b*100));
    SoftPWMSetPercent(D4[0], (d4r*100));
    SoftPWMSetPercent(D4[1], (d4g*100));
    SoftPWMSetPercent(D4[2], (d4b*100));    
      
    // now fade up
    long timenow = millis();
    while(millis()<(timenow+t)){}
     
    for (int i=1; i <= 13; i++) {SoftPWMSetPercent(i, 5);} // Turn off - set to 5% brightness  
    // now fade down
    timenow = millis();
    while(millis()<(timenow+t)){}
  } 
}

void RadioIn_A_PulseWidth()
{
  if(digitalRead(RadioIn_A_PIN) == HIGH) {RadioIn_A_PW_Start = micros();}  // if the pin is high, its the start of an interrupt
  else
  {    
      RadioIn_A_PW = (int)(micros() - RadioIn_A_PW_Start);
      RadioIn_A_PW_Start = 0;
  }
}
